==> pulumi-azure-native-kotlin-2.19.0.0-sources.jar: com/pulumi/azurenative/edgeorder/kotlin/inputs/ProductDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.edgeorder.kotlin.inputs

import com.pulumi.azurenative.edgeorder.inputs.ProductDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Represents product details
 * @property hierarchyInformation Hierarchy of the product which uniquely identifies the product
 * @property optInAdditionalConfigurations List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
 */
public data class ProductDetailsArgs(
    public val hierarchyInformation: Output<HierarchyInformationArgs>,
    public val optInAdditionalConfigurations: Output<List<AdditionalConfigurationArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.edgeorder.inputs.ProductDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.edgeorder.inputs.ProductDetailsArgs =
        com.pulumi.azurenative.edgeorder.inputs.ProductDetailsArgs.builder()
            .hierarchyInformation(
                hierarchyInformation.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .optInAdditionalConfigurations(
                optInAdditionalConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [ProductDetailsArgs].
 */
@PulumiTagMarker
public class ProductDetailsArgsBuilder internal constructor() {
    private var hierarchyInformation: Output<HierarchyInformationArgs>? = null

    private var optInAdditionalConfigurations: Output<List<AdditionalConfigurationArgs>>? = null

    /**
     * @param value Hierarchy of the product which uniquely identifies the product
     */
    @JvmName("nknmxgjslvaqyqjb")
    public suspend fun hierarchyInformation(`value`: Output<HierarchyInformationArgs>) {
        this.hierarchyInformation = value
    }

    /**
     * @param value List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("yokliyemrybwjvsf")
    public suspend
    fun optInAdditionalConfigurations(`value`: Output<List<AdditionalConfigurationArgs>>) {
        this.optInAdditionalConfigurations = value
    }

    @JvmName("mronvonaswrdtabc")
    public suspend fun optInAdditionalConfigurations(
        vararg
        values: Output<AdditionalConfigurationArgs>,
    ) {
        this.optInAdditionalConfigurations = Output.all(values.asList())
    }

    /**
     * @param values List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("veakhnyafkmoeewl")
    public suspend
    fun optInAdditionalConfigurations(values: List<Output<AdditionalConfigurationArgs>>) {
        this.optInAdditionalConfigurations = Output.all(values)
    }

    /**
     * @param value Hierarchy of the product which uniquely identifies the product
     */
    @JvmName("uwbsoatcytvprift")
    public suspend fun hierarchyInformation(`value`: HierarchyInformationArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hierarchyInformation = mapped
    }

    /**
     * @param argument Hierarchy of the product which uniquely identifies the product
     */
    @JvmName("sapnlrfichlhaoqr")
    public suspend
    fun hierarchyInformation(argument: suspend HierarchyInformationArgsBuilder.() -> Unit) {
        val toBeMapped = HierarchyInformationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.hierarchyInformation = mapped
    }

    /**
     * @param value List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("uamtngggosgimvhi")
    public suspend fun optInAdditionalConfigurations(`value`: List<AdditionalConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.optInAdditionalConfigurations = mapped
    }

    /**
     * @param argument List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("oefwxflokcvfxgjj")
    public suspend
    fun optInAdditionalConfigurations(argument: List<suspend AdditionalConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AdditionalConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.optInAdditionalConfigurations = mapped
    }

    /**
     * @param argument List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("ibvpxxokffabjinw")
    public suspend fun optInAdditionalConfigurations(
        vararg
        argument: suspend AdditionalConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            AdditionalConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.optInAdditionalConfigurations = mapped
    }

    /**
     * @param argument List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("mjeycvqclqyhmiko")
    public suspend
    fun optInAdditionalConfigurations(argument: suspend AdditionalConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            AdditionalConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.optInAdditionalConfigurations = mapped
    }

    /**
     * @param values List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("acyoykjkrcpdtuws")
    public suspend fun optInAdditionalConfigurations(vararg values: AdditionalConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.optInAdditionalConfigurations = mapped
    }

    internal fun build(): ProductDetailsArgs = ProductDetailsArgs(
        hierarchyInformation = hierarchyInformation ?: throw
            PulumiNullFieldException("hierarchyInformation"),
        optInAdditionalConfigurations = optInAdditionalConfigurations,
    )
}

==> pulumi-azure-native-kotlin-2.28.0.0-sources.jar: com/pulumi/azurenative/edgeorder/kotlin/inputs/ProductDetailsArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.azurenative.edgeorder.kotlin.inputs

import com.pulumi.azurenative.edgeorder.inputs.ProductDetailsArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiNullFieldException
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.collections.List
import kotlin.jvm.JvmName

/**
 * Represents product details
 * @property hierarchyInformation Hierarchy of the product which uniquely identifies the product
 * @property optInAdditionalConfigurations List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
 */
public data class ProductDetailsArgs(
    public val hierarchyInformation: Output<HierarchyInformationArgs>,
    public val optInAdditionalConfigurations: Output<List<AdditionalConfigurationArgs>>? = null,
) : ConvertibleToJava<com.pulumi.azurenative.edgeorder.inputs.ProductDetailsArgs> {
    override fun toJava(): com.pulumi.azurenative.edgeorder.inputs.ProductDetailsArgs =
        com.pulumi.azurenative.edgeorder.inputs.ProductDetailsArgs.builder()
            .hierarchyInformation(
                hierarchyInformation.applyValue({ args0 ->
                    args0.let({ args0 ->
                        args0.toJava()
                    })
                }),
            )
            .optInAdditionalConfigurations(
                optInAdditionalConfigurations?.applyValue({ args0 ->
                    args0.map({ args0 -> args0.let({ args0 -> args0.toJava() }) })
                }),
            ).build()
}

/**
 * Builder for [ProductDetailsArgs].
 */
@PulumiTagMarker
public class ProductDetailsArgsBuilder internal constructor() {
    private var hierarchyInformation: Output<HierarchyInformationArgs>? = null

    private var optInAdditionalConfigurations: Output<List<AdditionalConfigurationArgs>>? = null

    /**
     * @param value Hierarchy of the product which uniquely identifies the product
     */
    @JvmName("fdwmxhaulkqfnhwi")
    public suspend fun hierarchyInformation(`value`: Output<HierarchyInformationArgs>) {
        this.hierarchyInformation = value
    }

    /**
     * @param value List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("anrdmuncfaumbgkx")
    public suspend
    fun optInAdditionalConfigurations(`value`: Output<List<AdditionalConfigurationArgs>>) {
        this.optInAdditionalConfigurations = value
    }

    @JvmName("lrswypujvqwjqnor")
    public suspend fun optInAdditionalConfigurations(
        vararg
        values: Output<AdditionalConfigurationArgs>,
    ) {
        this.optInAdditionalConfigurations = Output.all(values.asList())
    }

    /**
     * @param values List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("hysrftlfevgbushb")
    public suspend
    fun optInAdditionalConfigurations(values: List<Output<AdditionalConfigurationArgs>>) {
        this.optInAdditionalConfigurations = Output.all(values)
    }

    /**
     * @param value Hierarchy of the product which uniquely identifies the product
     */
    @JvmName("lhggftedrmmykauy")
    public suspend fun hierarchyInformation(`value`: HierarchyInformationArgs) {
        val toBeMapped = value
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.hierarchyInformation = mapped
    }

    /**
     * @param argument Hierarchy of the product which uniquely identifies the product
     */
    @JvmName("ttroogfapgxaigdk")
    public suspend
    fun hierarchyInformation(argument: suspend HierarchyInformationArgsBuilder.() -> Unit) {
        val toBeMapped = HierarchyInformationArgsBuilder().applySuspend { argument() }.build()
        val mapped = of(toBeMapped)
        this.hierarchyInformation = mapped
    }

    /**
     * @param value List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("vbyyrrmeqkrwcrte")
    public suspend fun optInAdditionalConfigurations(`value`: List<AdditionalConfigurationArgs>?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.optInAdditionalConfigurations = mapped
    }

    /**
     * @param argument List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("smctjpsjeppbmaon")
    public suspend
    fun optInAdditionalConfigurations(argument: List<suspend AdditionalConfigurationArgsBuilder.() -> Unit>) {
        val toBeMapped = argument.toList().map {
            AdditionalConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.optInAdditionalConfigurations = mapped
    }

    /**
     * @param argument List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("nleyggmxisbkewvx")
    public suspend fun optInAdditionalConfigurations(
        vararg
        argument: suspend AdditionalConfigurationArgsBuilder.() -> Unit,
    ) {
        val toBeMapped = argument.toList().map {
            AdditionalConfigurationArgsBuilder().applySuspend {
                it()
            }.build()
        }
        val mapped = of(toBeMapped)
        this.optInAdditionalConfigurations = mapped
    }

    /**
     * @param argument List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("vknfqjqomwbombgi")
    public suspend
    fun optInAdditionalConfigurations(argument: suspend AdditionalConfigurationArgsBuilder.() -> Unit) {
        val toBeMapped = listOf(
            AdditionalConfigurationArgsBuilder().applySuspend {
                argument()
            }.build(),
        )
        val mapped = of(toBeMapped)
        this.optInAdditionalConfigurations = mapped
    }

    /**
     * @param values List of additional configurations customer wants in the order item apart from the ones included in the base configuration.
     */
    @JvmName("pntabnkfbqrbnvre")
    public suspend fun optInAdditionalConfigurations(vararg values: AdditionalConfigurationArgs) {
        val toBeMapped = values.toList()
        val mapped = toBeMapped.let({ args0 -> of(args0) })
        this.optInAdditionalConfigurations = mapped
    }

    internal fun build(): ProductDetailsArgs = ProductDetailsArgs(
        hierarchyInformation = hierarchyInformation ?: throw
            PulumiNullFieldException("hierarchyInformation"),
        optInAdditionalConfigurations = optInAdditionalConfigurations,
    )
}
